@@ -90,6 +90,14 @@
    */ 
 #define FORCE_AENDERUNGEN_2013_09 0
 
+   /* die neue Version der Regel 20 wird zum 9. Dezember in den offiziellen IBAN-Regeln verffentlicht;
+    * die Bundesbank hat jedoch schon die Regelversion am 28. August verffentlicht, mit der Bitte, sie
+    * mglichst schon zum 9. September einzusetzen. Durch die neue Regelversion werden die Flle mit dem
+    * Rckgabewert IBAN_AMBIGUOUS_KTO komplett eliminiert.
+    */
+
+#define DB_NEUE_VERSION 1  /* bei 1: neue Version der DB-Regel benutzen */
+
 /* Debug-Version fr iban_gen in Perl aktivieren (zur Ausgabe der benutzten
  * Prfziffermethode in iban_gen()). Dies ist nur mglich, falls das Makro
  * DEBUG auf 1 gesetzt ist.
@@ -253,7 +261,7 @@
 #endif
 
    /* maximale Lnge fr Default-Suchpfad und Dateiname der LUT-Datei */
-#define LUT_PATH_LEN 128
+#define LUT_PATH_LEN 512
 
 /*
  * ######################################################################
@@ -516,7 +524,7 @@ extern const char *lut2_feld_namen[256];
 #define OK_HYPO_REQUIRES_KTO                    23
 #define OK_KTO_REPLACED_NO_PZ                   24
 #define OK_UNTERKONTO_ATTACHED                  25
-#line 308 "konto_check_h.lx"
+#line 316 "konto_check_h.lx"
 
 #define MAX_BLZ_CNT 30000  /* maximale Anzahl BLZ's in generate_lut() */
 
@@ -959,6 +967,7 @@ DLL_EXPORT int kto_check_write_default(char *lutfile,int block_id);
 DLL_EXPORT int lut_cleanup(void);
 
    /* IBAN-Sachen */
+DLL_EXPORT int ci_check(char *ci);
 DLL_EXPORT int iban_check(char *iban,int *retval);
 DLL_EXPORT const char *iban2bic(char *iban,int *retval,char *blz,char *kto);
 DLL_EXPORT char *iban_gen(char *kto,char *blz,int *retval);
